==> shelxle_1.0.513.orig.tar.bz2: shelxle-1.0.513/shx_helper.h <==
#ifndef SHX_HELPER_H
#define SHX_HELPER_H
#include <QtCore>
QStringList shxToolTips =(QStringList()<< "TITL [ ]"<<
"CELL wavelength[A] a[A] b[A] c[A] alpha[°] beta[°] gamma[°]"<<
"ZERR Z esd(a) esd(b) esd(c) esd(alpha) esd(beta) esd(gamma)"<<
"LATT N  N= 1=>P, 2=>I, 3=>R, 4=>F, 5=>A, 6=>B, 7=>C. "<<
"SYMM symmetry operation"<<
"SFAC elements or \nSFAC label a1 b1 a2 b2 a3 b3 a4 b4 c f' f'' mu r wt"<<
"DISP E f' f'' [#] mu [#]"<<
"UNIT n1 n2 ..."<<
"LAUE E"<<
"REM the rest of the line is a comment"<<
"MORE m ,sets the verbosity m=0..3"<<
"TIME t[s]"<<
"END end of input"<<
"HKLF n"<<"OMIT s[-2] 2Theta(lim)[180] or\nOMIT h k l"<<"SHEL lowres[infinite] highres[0]"<<
"BASF scale factors"<<"TWIN 3x3 matrix [-1 0 0 0 -1 0 0 0 -1] n[2]"<<"EXTI x[0]"<<
"SWAT g[0] U[2]"<<"HOPE nh [1]"<<"MERG n[2]"<<"SPEC del[0.2]"<<"RESI class[ ] number[0] alias"<<
"MOVE dx[0] dy[0] dz[0] sign[1]"<<"ANIS n\nANIS names"<<
"AFIX mn d[#] sof[11] U[10.08]"<<"HFIX mn U[#] d[#] atomnames"
<<"FRAG code[17] a[1] b[1] c[1] alpha[90] beta[90] gamma[90]"<<
"FEND \nThis must immediately follow the last atom of a FRAG fragment."<<"EXYZ atomnames"<<
"EADP atomnames"<<"EQIV $n symmetry operation"<<"CONN bmax[12] r[#] atomnames or \nCONN bmax[12]"<<
"BIND atom1 atom2"<<"FREE atom1 atom2"<<"DFIX d s[0.02] atom pairs"<<"DANG d s[0.04] atom pairs"
<<"BUMP s [0.02]"<<"SAME s1[0.02] s2[0.02] atomnames"<<"SADI s[0.02] atom pairs"<<
"CHIV V[0] s[0.1] atomnames"<<"FLAT s[0.1] four or more atoms"<<
"DELU s1[0.01] s2[0.01] atomnames"<<"DEFS sd[0.02] sf[0.1] su[0.01] ss[0.04] maxsof[1]"<<
"SIMU s[0.04] st[0.08] dmax[1.7] atomnames"<<"ISOR s[0.1] st[0.2] atomnames"<<
"NCSY DN sd[0.1] su[0.05] atoms"<<"SUMP c sigma c1 m1 c2 m2 ..."<<
"L.S. nls[0] nrf[0] nextra[0] maxvec[511]"<<"CGLS nls[0] nrf[0] nextra[0] maxvec[511]"<<
"BLOC n1 n2 atomnames"<<"DAMP damp[0.7] limse[15]"<<"STIR sres step[0.01]"<<
"WGHT a[0.1] b[0] c[0] d[0] e[0] f[.33333]"<<"FVAR osf[1] free variables"<<
"BOND atomnames"<<"CONF atomnames"<<"MPLA na atomnames"<<"RTAB codename atomnames"<<
"HTAB dh[2.0]\nHTAB donor-atom acceptor-atom"<<"LIST m[#] mult[1]"<<"ACTA 2thetafull[#]"<<
"SIZE dx dy dz"<<"TEMP T[20]"<<"WPDB n[1]"<<"FMAP code[2] axis[#] nl[53]"<<
"GRID sl[#] sa[#] sd[#] dl[#] da[#] dd[#]"<<"PLAN npeaks[20] d1[#] d2[#]"<<
"MOLE n"
);



#endif // SHX_HELPER_H

==> shelxle_1.0.564.orig.tar.bz2: shelxle-1.0.564/shx_helper.h <==
#ifndef SHX_HELPER_H
#define SHX_HELPER_H
#include <QtCore>
QStringList shxToolTips =(QStringList()<< "TITL [ ]"<<
"CELL wavelength[A] a[A] b[A] c[A] alpha[°] beta[°] gamma[°]"<<
"ZERR Z esd(a) esd(b) esd(c) esd(alpha) esd(beta) esd(gamma)"<<
"LATT N  N= 1=>P, 2=>I, 3=>R, 4=>F, 5=>A, 6=>B, 7=>C. "<<
"SYMM symmetry operation"<<
"SFAC elements or \nSFAC label a1 b1 a2 b2 a3 b3 a4 b4 c f' f'' mu r wt"<<
"DISP E f' f'' [#] mu [#]"<<
"UNIT n1 n2 ..."<<
"LAUE E"<<
"REM the rest of the line is a comment"<<
"MORE m ,sets the verbosity m=0..3"<<
"TIME t[s]"<<
"END end of input"<<
"HKLF n"<<"OMIT s[-2] 2Theta(lim)[180] or\nOMIT h k l"<<"SHEL lowres[infinite] highres[0]"<<
"BASF scale factors"<<"TWIN 3x3 matrix [-1 0 0 0 -1 0 0 0 -1] n[2]"<<"EXTI x[0]"<<
"SWAT g[0] U[2]"<<"HOPE nh [1]"<<"MERG n[2]"<<"SPEC del[0.2]"<<"RESI class[ ] number[0] alias"<<
"MOVE dx[0] dy[0] dz[0] sign[1]"<<"ANIS n\nANIS names"<<
"AFIX mn d[#] sof[11] U[10.08]"<<"HFIX mn U[#] d[#] atomnames"
<<"FRAG code[17] a[1] b[1] c[1] alpha[90] beta[90] gamma[90]"<<
"FEND \nThis must immediately follow the last atom of a FRAG fragment."<<"EXYZ atomnames"<<
"EADP atomnames"<<"EQIV $n symmetry operation"<<"CONN bmax[12] r[#] atomnames or \nCONN bmax[12]"<<
"BIND atom1 atom2"<<"FREE atom1 atom2"<<"DFIX d s[0.02] atom pairs"<<"DANG d s[0.04] atom pairs"
<<"BUMP s [0.02]"<<"SAME s1[0.02] s2[0.02] atomnames"<<"SADI s[0.02] atom pairs"<<
"CHIV V[0] s[0.1] atomnames"<<"FLAT s[0.1] four or more atoms"<<
"DELU s1[0.01] s2[0.01] atomnames"<<"DEFS sd[0.02] sf[0.1] su[0.01] ss[0.04] maxsof[1]"<<
"SIMU s[0.04] st[0.08] dmax[1.7] atomnames"<<"ISOR s[0.1] st[0.2] atomnames"<<
"NCSY DN sd[0.1] su[0.05] atoms"<<"SUMP c sigma c1 m1 c2 m2 ..."<<
"L.S. nls[0] nrf[0] nextra[0] maxvec[511]"<<"CGLS nls[0] nrf[0] nextra[0] maxvec[511]"<<
"BLOC n1 n2 atomnames"<<"DAMP damp[0.7] limse[15]"<<"STIR sres step[0.01]"<<
"WGHT a[0.1] b[0] c[0] d[0] e[0] f[.33333]"<<"FVAR osf[1] free variables"<<
"BOND atomnames"<<"CONF atomnames"<<"MPLA na atomnames"<<"RTAB codename atomnames"<<
"HTAB dh[2.0]\nHTAB donor-atom acceptor-atom"<<"LIST m[#] mult[1]"<<"ACTA 2thetafull[#]"<<
"SIZE dx dy dz"<<"TEMP T[20]"<<"WPDB n[1]"<<"FMAP code[2] axis[#] nl[53]"<<
"GRID sl[#] sa[#] sd[#] dl[#] da[#] dd[#]"<<"PLAN npeaks[20] d1[#] d2[#]"<<
"MOLE n"<<
"XNPD restrain against non-positive-definite atoms"<<
"REST"<<
"CHAN chain id for pdb "<<
"RIGU rigid body restraint"<<
"FLAP"<<
"RNUM N offset n to add to all following resi numbers"<<
"SOCC X[11.0] reset occupancy to X for the following atoms"<<
"PRIG x"<<
"WIGL x"<<
"RANG angle restraints"<<
"TANG torsion anghle restraints"<<
"ADDA O2T_999 etc. add atoms to residue so that H-restrains are obeyed."<<
"STAG torsion angle restraint for staggered"
);



#endif // SHX_HELPER_H
